# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/work_os.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61\x64min/v1/work_os.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x15\n\x13GetDirectoryRequest\"I\n\x14GetDirectoryResponse\x12\x31\n\tdirectory\x18\x01 \x01(\x0b\x32\x13.admin.v1.DirectoryR\tdirectory\"\xa7\x01\n\tDirectory\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x15\n\x06idp_id\x18\x03 \x01(\tR\x05idpId\x12!\n\x0c\x64irectory_id\x18\x04 \x01(\tR\x0b\x64irectoryId\x12\x1d\n\ncreated_at\x18\x05 \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x06 \x01(\tR\tupdatedAt\"/\n\x1dGetGroupsByDirectoryIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"V\n\x1eGetGroupsByDirectoryIdResponse\x12\x34\n\x06groups\x18\x01 \x03(\x0b\x32\x1c.admin.v1.DirectorySyncGroupR\x06groups\".\n\x1cGetUsersByDirectoryIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"I\n\x1dGetUsersByDirectoryIdResponse\x12(\n\x05users\x18\x01 \x03(\x0b\x32\x12.admin.v1.WorkUserR\x05users\"+\n\x19GetWorkOsGroupByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"P\n\x1aGetWorkOsGroupByIdResponse\x12\x32\n\x05group\x18\x01 \x01(\x0b\x32\x1c.admin.v1.DirectorySyncGroupR\x05group\"\xe5\x01\n\x12\x44irectorySyncGroup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x15\n\x06idp_id\x18\x03 \x01(\tR\x05idpId\x12!\n\x0c\x64irectory_id\x18\x04 \x01(\tR\x0b\x64irectoryId\x12\x1d\n\ncreated_at\x18\x05 \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x06 \x01(\tR\tupdatedAt\x12\x33\n\x16mapped_formal_group_id\x18\x07 \x01(\tR\x13mappedFormalGroupId\"O\n\tUserEmail\x12\x18\n\x07primary\x18\x01 \x01(\x08R\x07primary\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\"G\n\tUserGroup\x12\x16\n\x06object\x18\x01 \x01(\tR\x06object\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\"\xca\x02\n\x08WorkUser\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06idp_id\x18\x02 \x01(\tR\x05idpId\x12!\n\x0c\x64irectory_id\x18\x03 \x01(\tR\x0b\x64irectoryId\x12\x1a\n\x08username\x18\x04 \x01(\tR\x08username\x12+\n\x06\x65mails\x18\x05 \x03(\x0b\x32\x13.admin.v1.UserEmailR\x06\x65mails\x12\x1d\n\nfirst_name\x18\x07 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x08 \x01(\tR\x08lastName\x12\x1b\n\tjob_title\x18\t \x01(\tR\x08jobTitle\x12\x14\n\x05state\x18\n \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\x0b \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0c \x01(\tR\tupdatedAt\"1\n\x05Users\x12(\n\x05users\x18\x01 \x03(\x0b\x32\x12.admin.v1.WorkUserR\x05users\"\xf9\x01\n\x05Group\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x16\n\x06status\x18\x05 \x01(\tR\x06status\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x19\n\x08user_ids\x18\x07 \x03(\tR\x07userIds\x12$\n\x0e\x64sync_group_id\x18\x08 \x01(\tR\x0c\x64syncGroupId\"l\n\tGroupPair\x12(\n\x07\x66_group\x18\x01 \x01(\x0b\x32\x0f.admin.v1.GroupR\x06\x66Group\x12\x35\n\x07\x64_group\x18\x02 \x01(\x0b\x32\x1c.admin.v1.DirectorySyncGroupR\x06\x64Group\"\x1b\n\x19GetDirectoryGroupsRequest\"\x88\x03\n\x1aGetDirectoryGroupsResponse\x12#\n\rdirectory_ids\x18\x01 \x03(\tR\x0c\x64irectoryIds\x12*\n\x08\x66_groups\x18\x02 \x03(\x0b\x32\x0f.admin.v1.GroupR\x07\x66Groups\x12\x37\n\x08\x64_groups\x18\x03 \x03(\x0b\x32\x1c.admin.v1.DirectorySyncGroupR\x07\x64Groups\x12\x34\n\x0bgroup_pairs\x18\x04 \x03(\x0b\x32\x13.admin.v1.GroupPairR\ngroupPairs\x12Y\n\rd_group_users\x18\x05 \x03(\x0b\x32\x35.admin.v1.GetDirectoryGroupsResponse.DGroupUsersEntryR\x0b\x64GroupUsers\x1aO\n\x10\x44GroupUsersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x0f.admin.v1.UsersR\x05value:\x02\x38\x01\"\x95\x02\n\x1fUpdateDirectoryGroupSyncRequest\x12\x1c\n\nf_group_id\x18\x01 \x01(\tR\x08\x66GroupId\x12\x1c\n\nd_group_id\x18\x02 \x01(\tR\x08\x64GroupId\x12p\n\x13\x64\x65selected_user_ids\x18\x03 \x03(\x0b\x32@.admin.v1.UpdateDirectoryGroupSyncRequest.DeselectedUserIdsEntryR\x11\x64\x65selectedUserIds\x1a\x44\n\x16\x44\x65selectedUserIdsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x08R\x05value:\x02\x38\x01\"@\n UpdateDirectoryGroupSyncResponse\x12\x1c\n\nf_group_id\x18\x01 \x01(\tR\x08\x66GroupId\"6\n\x15GetDSyncPortalRequest\x12\x1d\n\nauth_token\x18\x01 \x01(\tR\tauthToken\",\n\x16GetDSyncPortalResponse\x12\x12\n\x04link\x18\x01 \x01(\tR\x04link2\xbe\x05\n\x0c\x44SyncService\x12M\n\x0cGetDirectory\x12\x1d.admin.v1.GetDirectoryRequest\x1a\x1e.admin.v1.GetDirectoryResponse\x12k\n\x16GetGroupsByDirectoryId\x12\'.admin.v1.GetGroupsByDirectoryIdRequest\x1a(.admin.v1.GetGroupsByDirectoryIdResponse\x12h\n\x15GetUsersByDirectoryId\x12&.admin.v1.GetUsersByDirectoryIdRequest\x1a\'.admin.v1.GetUsersByDirectoryIdResponse\x12_\n\x12GetWorkOsGroupById\x12#.admin.v1.GetWorkOsGroupByIdRequest\x1a$.admin.v1.GetWorkOsGroupByIdResponse\x12_\n\x12GetDirectoryGroups\x12#.admin.v1.GetDirectoryGroupsRequest\x1a$.admin.v1.GetDirectoryGroupsResponse\x12q\n\x18UpdateDirectoryGroupSync\x12).admin.v1.UpdateDirectoryGroupSyncRequest\x1a*.admin.v1.UpdateDirectoryGroupSyncResponse\x12S\n\x0eGetDSyncPortal\x12\x1f.admin.v1.GetDSyncPortalRequest\x1a .admin.v1.GetDSyncPortalResponseB\xa6\x01\n\x0c\x63om.admin.v1B\x0bWorkOsProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.work_os_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\013WorkOsProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETDIRECTORYGROUPSRESPONSE_DGROUPUSERSENTRY']._options = None
  _globals['_GETDIRECTORYGROUPSRESPONSE_DGROUPUSERSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST_DESELECTEDUSERIDSENTRY']._options = None
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST_DESELECTEDUSERIDSENTRY']._serialized_options = b'8\001'
  _globals['_GETDIRECTORYREQUEST']._serialized_start=69
  _globals['_GETDIRECTORYREQUEST']._serialized_end=90
  _globals['_GETDIRECTORYRESPONSE']._serialized_start=92
  _globals['_GETDIRECTORYRESPONSE']._serialized_end=165
  _globals['_DIRECTORY']._serialized_start=168
  _globals['_DIRECTORY']._serialized_end=335
  _globals['_GETGROUPSBYDIRECTORYIDREQUEST']._serialized_start=337
  _globals['_GETGROUPSBYDIRECTORYIDREQUEST']._serialized_end=384
  _globals['_GETGROUPSBYDIRECTORYIDRESPONSE']._serialized_start=386
  _globals['_GETGROUPSBYDIRECTORYIDRESPONSE']._serialized_end=472
  _globals['_GETUSERSBYDIRECTORYIDREQUEST']._serialized_start=474
  _globals['_GETUSERSBYDIRECTORYIDREQUEST']._serialized_end=520
  _globals['_GETUSERSBYDIRECTORYIDRESPONSE']._serialized_start=522
  _globals['_GETUSERSBYDIRECTORYIDRESPONSE']._serialized_end=595
  _globals['_GETWORKOSGROUPBYIDREQUEST']._serialized_start=597
  _globals['_GETWORKOSGROUPBYIDREQUEST']._serialized_end=640
  _globals['_GETWORKOSGROUPBYIDRESPONSE']._serialized_start=642
  _globals['_GETWORKOSGROUPBYIDRESPONSE']._serialized_end=722
  _globals['_DIRECTORYSYNCGROUP']._serialized_start=725
  _globals['_DIRECTORYSYNCGROUP']._serialized_end=954
  _globals['_USEREMAIL']._serialized_start=956
  _globals['_USEREMAIL']._serialized_end=1035
  _globals['_USERGROUP']._serialized_start=1037
  _globals['_USERGROUP']._serialized_end=1108
  _globals['_WORKUSER']._serialized_start=1111
  _globals['_WORKUSER']._serialized_end=1441
  _globals['_USERS']._serialized_start=1443
  _globals['_USERS']._serialized_end=1492
  _globals['_GROUP']._serialized_start=1495
  _globals['_GROUP']._serialized_end=1744
  _globals['_GROUPPAIR']._serialized_start=1746
  _globals['_GROUPPAIR']._serialized_end=1854
  _globals['_GETDIRECTORYGROUPSREQUEST']._serialized_start=1856
  _globals['_GETDIRECTORYGROUPSREQUEST']._serialized_end=1883
  _globals['_GETDIRECTORYGROUPSRESPONSE']._serialized_start=1886
  _globals['_GETDIRECTORYGROUPSRESPONSE']._serialized_end=2278
  _globals['_GETDIRECTORYGROUPSRESPONSE_DGROUPUSERSENTRY']._serialized_start=2199
  _globals['_GETDIRECTORYGROUPSRESPONSE_DGROUPUSERSENTRY']._serialized_end=2278
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST']._serialized_start=2281
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST']._serialized_end=2558
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST_DESELECTEDUSERIDSENTRY']._serialized_start=2490
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST_DESELECTEDUSERIDSENTRY']._serialized_end=2558
  _globals['_UPDATEDIRECTORYGROUPSYNCRESPONSE']._serialized_start=2560
  _globals['_UPDATEDIRECTORYGROUPSYNCRESPONSE']._serialized_end=2624
  _globals['_GETDSYNCPORTALREQUEST']._serialized_start=2626
  _globals['_GETDSYNCPORTALREQUEST']._serialized_end=2680
  _globals['_GETDSYNCPORTALRESPONSE']._serialized_start=2682
  _globals['_GETDSYNCPORTALRESPONSE']._serialized_end=2726
  _globals['_DSYNCSERVICE']._serialized_start=2729
  _globals['_DSYNCSERVICE']._serialized_end=3431
# @@protoc_insertion_point(module_scope)



from .types.v1 import flat_dataplane_pb2 as _flat_dataplane_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateDataplaneRequest(_message.Message):
    __slots__ = ["name", "region", "cloud_account_id", "availability_zone", "vpc_peering"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    CLOUD_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    AVAILABILITY_ZONE_FIELD_NUMBER: _ClassVar[int]
    VPC_PEERING_FIELD_NUMBER: _ClassVar[int]
    name: str
    region: str
    cloud_account_id: str
    availability_zone: int
    vpc_peering: bool
    def __init__(self, name: _Optional[str] = ..., region: _Optional[str] = ..., cloud_account_id: _Optional[str] = ..., availability_zone: _Optional[int] = ..., vpc_peering: bool = ...) -> None: ...

class CreateDataplaneResponse(_message.Message):
    __slots__ = ["dataplane"]
    DATAPLANE_FIELD_NUMBER: _ClassVar[int]
    dataplane: _flat_dataplane_pb2.FlatDataplane
    def __init__(self, dataplane: _Optional[_Union[_flat_dataplane_pb2.FlatDataplane, _Mapping]] = ...) -> None: ...

class GetDataplaneByIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDataplaneByIdResponse(_message.Message):
    __slots__ = ["dataplane"]
    DATAPLANE_FIELD_NUMBER: _ClassVar[int]
    dataplane: _flat_dataplane_pb2.FlatDataplane
    def __init__(self, dataplane: _Optional[_Union[_flat_dataplane_pb2.FlatDataplane, _Mapping]] = ...) -> None: ...

class DeleteDataplaneRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteDataplaneResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateDataplaneRoutesRequest(_message.Message):
    __slots__ = ["dataplane_id", "destination_cidr_block", "transit_gateway_id", "vpc_peering_connection_id"]
    DATAPLANE_ID_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_CIDR_BLOCK_FIELD_NUMBER: _ClassVar[int]
    TRANSIT_GATEWAY_ID_FIELD_NUMBER: _ClassVar[int]
    VPC_PEERING_CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    dataplane_id: str
    destination_cidr_block: str
    transit_gateway_id: str
    vpc_peering_connection_id: str
    def __init__(self, dataplane_id: _Optional[str] = ..., destination_cidr_block: _Optional[str] = ..., transit_gateway_id: _Optional[str] = ..., vpc_peering_connection_id: _Optional[str] = ...) -> None: ...

class CreateDataplaneRoutesResponse(_message.Message):
    __slots__ = ["dataplane_routes"]
    DATAPLANE_ROUTES_FIELD_NUMBER: _ClassVar[int]
    dataplane_routes: _flat_dataplane_pb2.DataplaneTransitGatewayRoutes
    def __init__(self, dataplane_routes: _Optional[_Union[_flat_dataplane_pb2.DataplaneTransitGatewayRoutes, _Mapping]] = ...) -> None: ...

class GetDataplaneRoutesByIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDataplaneRoutesByIdResponse(_message.Message):
    __slots__ = ["dataplane_routes"]
    DATAPLANE_ROUTES_FIELD_NUMBER: _ClassVar[int]
    dataplane_routes: _flat_dataplane_pb2.DataplaneTransitGatewayRoutes
    def __init__(self, dataplane_routes: _Optional[_Union[_flat_dataplane_pb2.DataplaneTransitGatewayRoutes, _Mapping]] = ...) -> None: ...

class DeleteDataplaneRoutesRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteDataplaneRoutesResponse(_message.Message):
    __slots__ = ["message"]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class CreateAwsConnectionSessionRequest(_message.Message):
    __slots__ = ["cloud_account_name", "cloud_account_region"]
    CLOUD_ACCOUNT_NAME_FIELD_NUMBER: _ClassVar[int]
    CLOUD_ACCOUNT_REGION_FIELD_NUMBER: _ClassVar[int]
    cloud_account_name: str
    cloud_account_region: str
    def __init__(self, cloud_account_name: _Optional[str] = ..., cloud_account_region: _Optional[str] = ...) -> None: ...

class CreateAwsConnectionSessionResponse(_message.Message):
    __slots__ = ["cloud_integration"]
    CLOUD_INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    cloud_integration: _flat_dataplane_pb2.CloudIntegration
    def __init__(self, cloud_integration: _Optional[_Union[_flat_dataplane_pb2.CloudIntegration, _Mapping]] = ...) -> None: ...

class DeleteAwsConnectionSessionRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetIntegrationsCloudAccountByIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetIntegrationsCloudAccountByIdResponse(_message.Message):
    __slots__ = ["integration"]
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: _flat_dataplane_pb2.CloudIntegration
    def __init__(self, integration: _Optional[_Union[_flat_dataplane_pb2.CloudIntegration, _Mapping]] = ...) -> None: ...

class GetIntegrationsCloudAccountsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetIntegrationsCloudAccountsResponse(_message.Message):
    __slots__ = ["integrations"]
    INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    integrations: _containers.RepeatedCompositeFieldContainer[_flat_dataplane_pb2.CloudIntegration]
    def __init__(self, integrations: _Optional[_Iterable[_Union[_flat_dataplane_pb2.CloudIntegration, _Mapping]]] = ...) -> None: ...

class CreateGcpConnectionSessionRequest(_message.Message):
    __slots__ = ["project_id"]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class CreateGcpConnectionSessionResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteAwsConnectionSessionResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetDataplaneStacksByCloudAccountIdRequest(_message.Message):
    __slots__ = ["cloud_account_id"]
    CLOUD_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    cloud_account_id: str
    def __init__(self, cloud_account_id: _Optional[str] = ...) -> None: ...

class GetDataplaneStacksByCloudAccountIdResponse(_message.Message):
    __slots__ = ["dataplanes"]
    DATAPLANES_FIELD_NUMBER: _ClassVar[int]
    dataplanes: _containers.RepeatedCompositeFieldContainer[_flat_dataplane_pb2.FlatDataplane]
    def __init__(self, dataplanes: _Optional[_Iterable[_Union[_flat_dataplane_pb2.FlatDataplane, _Mapping]]] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
from .types.v1 import policy_pb2 as _policy_pb2
from .types.v1 import list_metadata_pb2 as _list_metadata_pb2
from ...validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PolicyRuleType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    POLICY_RULE_TYPE_UNSPECIFIED: _ClassVar[PolicyRuleType]
    POLICY_RULE_TYPE_SESSION: _ClassVar[PolicyRuleType]
    POLICY_RULE_TYPE_PRE: _ClassVar[PolicyRuleType]
    POLICY_RULE_TYPE_POST: _ClassVar[PolicyRuleType]

class PolicyType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    POLICY_TYPE_UNSPECIFIED: _ClassVar[PolicyType]
    POLICY_TYPE_ALLOW: _ClassVar[PolicyType]
    POLICY_TYPE_BLOCK: _ClassVar[PolicyType]
    POLICY_TYPE_REWRITE: _ClassVar[PolicyType]
    POLICY_TYPE_ENCRYPT: _ClassVar[PolicyType]
    POLICY_TYPE_DECRYPT: _ClassVar[PolicyType]
    POLICY_TYPE_MASK: _ClassVar[PolicyType]
POLICY_RULE_TYPE_UNSPECIFIED: PolicyRuleType
POLICY_RULE_TYPE_SESSION: PolicyRuleType
POLICY_RULE_TYPE_PRE: PolicyRuleType
POLICY_RULE_TYPE_POST: PolicyRuleType
POLICY_TYPE_UNSPECIFIED: PolicyType
POLICY_TYPE_ALLOW: PolicyType
POLICY_TYPE_BLOCK: PolicyType
POLICY_TYPE_REWRITE: PolicyType
POLICY_TYPE_ENCRYPT: PolicyType
POLICY_TYPE_DECRYPT: PolicyType
POLICY_TYPE_MASK: PolicyType

class CreatePolicySuggestionRequest(_message.Message):
    __slots__ = ["name", "description"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class CreatePolicySuggestionResponse(_message.Message):
    __slots__ = ["suggestion"]
    SUGGESTION_FIELD_NUMBER: _ClassVar[int]
    suggestion: str
    def __init__(self, suggestion: _Optional[str] = ...) -> None: ...

class DeletePolicyRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeletePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class EvaluatePolicyValidityRequest(_message.Message):
    __slots__ = ["code"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: str
    def __init__(self, code: _Optional[str] = ...) -> None: ...

class EvaluatePolicyValidityResponse(_message.Message):
    __slots__ = ["valid", "ast", "error"]
    VALID_FIELD_NUMBER: _ClassVar[int]
    AST_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    valid: bool
    ast: str
    error: str
    def __init__(self, valid: bool = ..., ast: _Optional[str] = ..., error: _Optional[str] = ...) -> None: ...

class DryRunPoliciesRequest(_message.Message):
    __slots__ = ["policy_rule_type", "application_name", "client_ip_address", "client_tls", "statement_type", "db_name", "schema_paths", "table_paths", "column_tags", "column_name", "column_path", "data_label", "sidecar_id", "aws", "columns", "user_id"]
    POLICY_RULE_TYPE_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_NAME_FIELD_NUMBER: _ClassVar[int]
    CLIENT_IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CLIENT_TLS_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    DB_NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_PATHS_FIELD_NUMBER: _ClassVar[int]
    TABLE_PATHS_FIELD_NUMBER: _ClassVar[int]
    COLUMN_TAGS_FIELD_NUMBER: _ClassVar[int]
    COLUMN_NAME_FIELD_NUMBER: _ClassVar[int]
    COLUMN_PATH_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    SIDECAR_ID_FIELD_NUMBER: _ClassVar[int]
    AWS_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    policy_rule_type: PolicyRuleType
    application_name: str
    client_ip_address: str
    client_tls: bool
    statement_type: str
    db_name: str
    schema_paths: _containers.RepeatedScalarFieldContainer[str]
    table_paths: _containers.RepeatedScalarFieldContainer[str]
    column_tags: _containers.RepeatedScalarFieldContainer[str]
    column_name: str
    column_path: str
    data_label: str
    sidecar_id: str
    aws: AWS
    columns: _containers.RepeatedCompositeFieldContainer[ColumnPolicy]
    user_id: str
    def __init__(self, policy_rule_type: _Optional[_Union[PolicyRuleType, str]] = ..., application_name: _Optional[str] = ..., client_ip_address: _Optional[str] = ..., client_tls: bool = ..., statement_type: _Optional[str] = ..., db_name: _Optional[str] = ..., schema_paths: _Optional[_Iterable[str]] = ..., table_paths: _Optional[_Iterable[str]] = ..., column_tags: _Optional[_Iterable[str]] = ..., column_name: _Optional[str] = ..., column_path: _Optional[str] = ..., data_label: _Optional[str] = ..., sidecar_id: _Optional[str] = ..., aws: _Optional[_Union[AWS, _Mapping]] = ..., columns: _Optional[_Iterable[_Union[ColumnPolicy, _Mapping]]] = ..., user_id: _Optional[str] = ...) -> None: ...

class ColumnPolicy(_message.Message):
    __slots__ = ["index", "parent_column_path", "parent_column_type", "parent_is_array", "parent_index", "parent_data_type", "sub_column", "data_type", "name", "path", "tags", "data_label", "value", "row_level_usage", "array_index", "json_path"]
    class RowLevelUsageEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    INDEX_FIELD_NUMBER: _ClassVar[int]
    PARENT_COLUMN_PATH_FIELD_NUMBER: _ClassVar[int]
    PARENT_COLUMN_TYPE_FIELD_NUMBER: _ClassVar[int]
    PARENT_IS_ARRAY_FIELD_NUMBER: _ClassVar[int]
    PARENT_INDEX_FIELD_NUMBER: _ClassVar[int]
    PARENT_DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    SUB_COLUMN_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    ROW_LEVEL_USAGE_FIELD_NUMBER: _ClassVar[int]
    ARRAY_INDEX_FIELD_NUMBER: _ClassVar[int]
    JSON_PATH_FIELD_NUMBER: _ClassVar[int]
    index: int
    parent_column_path: str
    parent_column_type: str
    parent_is_array: bool
    parent_index: int
    parent_data_type: str
    sub_column: bool
    data_type: str
    name: str
    path: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    data_label: str
    value: _any_pb2.Any
    row_level_usage: _containers.ScalarMap[str, int]
    array_index: int
    json_path: str
    def __init__(self, index: _Optional[int] = ..., parent_column_path: _Optional[str] = ..., parent_column_type: _Optional[str] = ..., parent_is_array: bool = ..., parent_index: _Optional[int] = ..., parent_data_type: _Optional[str] = ..., sub_column: bool = ..., data_type: _Optional[str] = ..., name: _Optional[str] = ..., path: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ..., data_label: _Optional[str] = ..., value: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., row_level_usage: _Optional[_Mapping[str, int]] = ..., array_index: _Optional[int] = ..., json_path: _Optional[str] = ...) -> None: ...

class AWSAccount(_message.Message):
    __slots__ = ["account_id", "region"]
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    account_id: str
    region: str
    def __init__(self, account_id: _Optional[str] = ..., region: _Optional[str] = ...) -> None: ...

class AWSEC2(_message.Message):
    __slots__ = ["instance_id"]
    INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    instance_id: str
    def __init__(self, instance_id: _Optional[str] = ...) -> None: ...

class AWSECS(_message.Message):
    __slots__ = ["cluster_name", "service_name", "task_id", "container_name"]
    CLUSTER_NAME_FIELD_NUMBER: _ClassVar[int]
    SERVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    CONTAINER_NAME_FIELD_NUMBER: _ClassVar[int]
    cluster_name: str
    service_name: str
    task_id: str
    container_name: str
    def __init__(self, cluster_name: _Optional[str] = ..., service_name: _Optional[str] = ..., task_id: _Optional[str] = ..., container_name: _Optional[str] = ...) -> None: ...

class AWS(_message.Message):
    __slots__ = ["account", "ec2", "ecs"]
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    EC2_FIELD_NUMBER: _ClassVar[int]
    ECS_FIELD_NUMBER: _ClassVar[int]
    account: AWSAccount
    ec2: AWSEC2
    ecs: AWSECS
    def __init__(self, account: _Optional[_Union[AWSAccount, _Mapping]] = ..., ec2: _Optional[_Union[AWSEC2, _Mapping]] = ..., ecs: _Optional[_Union[AWSECS, _Mapping]] = ...) -> None: ...

class DryRunPoliciesResponse(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedScalarFieldContainer[PolicyType]
    def __init__(self, results: _Optional[_Iterable[_Union[PolicyType, str]]] = ...) -> None: ...

class CreatePolicyRequest(_message.Message):
    __slots__ = ["name", "description", "code", "notification", "owners", "source_type", "active"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    code: str
    notification: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    source_type: str
    active: bool
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., code: _Optional[str] = ..., notification: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., source_type: _Optional[str] = ..., active: bool = ...) -> None: ...

class CreatePolicyV2Request(_message.Message):
    __slots__ = ["name", "description", "code", "notification", "owners", "source_type", "active", "status"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    code: str
    notification: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    source_type: str
    active: bool
    status: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., code: _Optional[str] = ..., notification: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., source_type: _Optional[str] = ..., active: bool = ..., status: _Optional[str] = ...) -> None: ...

class CreatePolicyResponse(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.Policy
    def __init__(self, policy: _Optional[_Union[_policy_pb2.Policy, _Mapping]] = ...) -> None: ...

class CreatePolicyV2Response(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.PolicyV2
    def __init__(self, policy: _Optional[_Union[_policy_pb2.PolicyV2, _Mapping]] = ...) -> None: ...

class UpdatePolicyRequest(_message.Message):
    __slots__ = ["id", "source_type", "name", "description", "code", "notification", "owners", "active"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    source_type: str
    name: str
    description: str
    code: str
    notification: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    active: bool
    def __init__(self, id: _Optional[str] = ..., source_type: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., code: _Optional[str] = ..., notification: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., active: bool = ...) -> None: ...

class UpdatePolicyV2Request(_message.Message):
    __slots__ = ["id", "source_type", "name", "description", "code", "notification", "owners", "active", "status"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    source_type: str
    name: str
    description: str
    code: str
    notification: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    active: bool
    status: str
    def __init__(self, id: _Optional[str] = ..., source_type: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., code: _Optional[str] = ..., notification: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., active: bool = ..., status: _Optional[str] = ...) -> None: ...

class UpdatePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdatePolicyV2Response(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetPolicyRequest(_message.Message):
    __slots__ = ["policy_id"]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    policy_id: str
    def __init__(self, policy_id: _Optional[str] = ...) -> None: ...

class GetPolicyV2Request(_message.Message):
    __slots__ = ["policy_id"]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    policy_id: str
    def __init__(self, policy_id: _Optional[str] = ...) -> None: ...

class GetPolicyResponse(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.Policy
    def __init__(self, policy: _Optional[_Union[_policy_pb2.Policy, _Mapping]] = ...) -> None: ...

class GetPolicyV2Response(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.PolicyV2
    def __init__(self, policy: _Optional[_Union[_policy_pb2.PolicyV2, _Mapping]] = ...) -> None: ...

class GetPoliciesRequest(_message.Message):
    __slots__ = ["limit", "after", "before", "order"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    limit: int
    after: str
    before: str
    order: str
    def __init__(self, limit: _Optional[int] = ..., after: _Optional[str] = ..., before: _Optional[str] = ..., order: _Optional[str] = ...) -> None: ...

class GetPoliciesResponse(_message.Message):
    __slots__ = ["policies", "list_metadata"]
    POLICIES_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    policies: _containers.RepeatedCompositeFieldContainer[_policy_pb2.Policy]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, policies: _Optional[_Iterable[_Union[_policy_pb2.Policy, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Datahub(_message.Message):
    __slots__ = ["id", "webhook_secret", "organization_id", "name", "active", "generalized_metadata_service_url", "sync_direction", "synced_entities", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    WEBHOOK_SECRET_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    GENERALIZED_METADATA_SERVICE_URL_FIELD_NUMBER: _ClassVar[int]
    SYNC_DIRECTION_FIELD_NUMBER: _ClassVar[int]
    SYNCED_ENTITIES_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    webhook_secret: str
    organization_id: str
    name: str
    active: bool
    generalized_metadata_service_url: str
    sync_direction: str
    synced_entities: _containers.RepeatedScalarFieldContainer[str]
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., webhook_secret: _Optional[str] = ..., organization_id: _Optional[str] = ..., name: _Optional[str] = ..., active: bool = ..., generalized_metadata_service_url: _Optional[str] = ..., sync_direction: _Optional[str] = ..., synced_entities: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import column_pb2 as admin_dot_v1_dot_types_dot_v1_dot_column__pb2
from . import domain_pb2 as admin_dot_v1_dot_types_dot_v1_dot_domain__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61\x64min/v1/types/v1/log.proto\x12\x11\x61\x64min.v1.types.v1\x1a\x1e\x61\x64min/v1/types/v1/column.proto\x1a\x1e\x61\x64min/v1/types/v1/domain.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\x84\x02\n\x0fTriggeredPolicy\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\x12\x16\n\x06owners\x18\x02 \x03(\tR\x06owners\x12\x16\n\x06notify\x18\x03 \x01(\tR\x06notify\x12>\n\x0bpolicy_type\x18\x04 \x01(\x0e\x32\x1d.admin.v1.types.v1.PolicyTypeR\npolicyType\x12\x16\n\x06reason\x18\x05 \x01(\tR\x06reason\x12\'\n\x0f\x63ontextual_data\x18\x06 \x01(\tR\x0e\x63ontextualData\x12#\n\rpolicy_status\x18\x07 \x01(\tR\x0cpolicyStatus\"_\n\x15TriggeredFilterPolicy\x12\x1a\n\x08interval\x18\x01 \x01(\tR\x08interval\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x14\n\x05\x63ount\x18\x03 \x01(\x03R\x05\x63ount\"<\n\x19TriggeredDecryptionPolicy\x12\x1f\n\x0b\x63olumn_path\x18\x01 \x01(\tR\ncolumnPath\"x\n\x16TriggeredMaskingPolicy\x12\x1f\n\x0b\x63olumn_path\x18\x01 \x01(\tR\ncolumnPath\x12!\n\x0cmasking_type\x18\x02 \x01(\tR\x0bmaskingType\x12\x1a\n\x08typesafe\x18\x03 \x01(\x08R\x08typesafe\"\xdf\x01\n\x14TriggeredBlockPolicy\x12\x1f\n\x0bobject_type\x18\x01 \x01(\tR\nobjectType\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12!\n\x0cobject_paths\x18\x03 \x03(\tR\x0bobjectPaths\x12\x1a\n\x08multiple\x18\x04 \x01(\x08R\x08multiple\x12\x16\n\x06\x61\x63tion\x18\x05 \x01(\tR\x06\x61\x63tion\x12;\n\x1a\x64\x61tastore_is_default_block\x18\x06 \x01(\x08R\x17\x64\x61tastoreIsDefaultBlock\"J\n\x13TiggeredAllowPolicy\x12\x1f\n\x0bobject_type\x18\x01 \x01(\tR\nobjectType\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\"\xda\x10\n\nLogRequest\x12\x39\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12Q\n\x17sidecar_processing_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15sidecarProcessingTime\x12M\n\x15\x64\x61ta_store_start_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12\x64\x61taStoreStartTime\x12I\n\x13\x64\x61ta_store_end_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x64\x61taStoreEndTime\x12V\n\x1a\x64\x61ta_store_processing_time\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x17\x64\x61taStoreProcessingTime\x12\x14\n\x05query\x18\x07 \x01(\tR\x05query\x12\x18\n\x07success\x18\x08 \x01(\x08R\x07success\x12#\n\rerror_message\x18\t \x01(\tR\x0c\x65rrorMessage\x12!\n\x0cstament_type\x18\n \x01(\tR\x0bstamentType\x12\'\n\x0freturned_tables\x18\x0b \x03(\tR\x0ereturnedTables\x12\x44\n\x10returned_columns\x18\x0c \x03(\x0b\x32\x19.admin.v1.types.v1.ColumnR\x0freturnedColumns\x12\x1f\n\x0b\x64\x61ta_volume\x18\r \x01(\x04R\ndataVolume\x12\x1e\n\x0b\x65nd_user_id\x18\x0e \x01(\tR\tendUserId\x12\x30\n\x15\x65nd_user_db_user_name\x18\x0f \x01(\tR\x11\x65ndUserDbUserName\x12\x31\n\x15\x65nd_user_external_ids\x18\x10 \x03(\tR\x12\x65ndUserExternalIds\x12#\n\rpolicy_action\x18\x11 \x01(\tR\x0cpolicyAction\x12.\n\x13returned_rows_count\x18\x12 \x01(\x03R\x11returnedRowsCount\x12@\n\x1dreturned_rows_count_by_server\x18\x13 \x01(\x03R\x19returnedRowsCountByServer\x12<\n\x1breturned_rows_count_to_user\x18\x14 \x01(\x03R\x17returnedRowsCountToUser\x12.\n\x13\x66iltered_rows_count\x18\x15 \x01(\x03R\x11\x66ilteredRowsCount\x12Q\n\x12triggered_policies\x18\x16 \x03(\x0b\x32\".admin.v1.types.v1.TriggeredPolicyR\x11triggeredPolicies\x12\x1b\n\ttenant_id\x18\x17 \x01(\tR\x08tenantId\x12M\n\x11row_level_metrics\x18\x18 \x03(\x0b\x32!.admin.v1.types.v1.RowLevelMetricR\x0frowLevelMetrics\x12\x31\n\x15tenant_id_column_name\x18\x19 \x01(\tR\x12tenantIdColumnName\x12\'\n\x0ftenant_mismatch\x18\x1a \x03(\tR\x0etenantMismatch\x12\x1f\n\x0b\x62ucket_name\x18\x1b \x01(\tR\nbucketName\x12\x1b\n\ts3_action\x18\x1c \x01(\tR\x08s3Action\x12\x46\n\x10returned_objects\x18\x1d \x03(\x0b\x32\x1b.admin.v1.types.v1.S3ObjectR\x0freturnedObjects\x12\x35\n\x17ssh_aws_connection_type\x18\x1e \x01(\tR\x14sshAwsConnectionType\x12\x1e\n\x0bssh_aws_arn\x18\x1f \x01(\tR\tsshAwsArn\x12&\n\x0f\x65nd_user_groups\x18  \x03(\tR\rendUserGroups\x12\x1f\n\x0buser_groups\x18! \x03(\tR\nuserGroups\x12\x16\n\x06groups\x18\" \x03(\tR\x06groups\x12 \n\x0b\x66ingerprint\x18# \x01(\tR\x0b\x66ingerprint\x12<\n\x0c\x64\x61ta_domains\x18$ \x03(\x0b\x32\x19.admin.v1.types.v1.DomainR\x0b\x64\x61taDomains\x12!\n\x0crequest_body\x18% \x01(\tR\x0brequestBody\x12#\n\rresponse_body\x18& \x01(\tR\x0cresponseBody\x12\x34\n\x16request_body_encrypted\x18\' \x01(\x08R\x14requestBodyEncrypted\x12\x36\n\x17response_body_encrypted\x18( \x01(\x08R\x15responseBodyEncrypted\x12H\n!request_body_post_policies_action\x18) \x01(\tR\x1drequestBodyPostPoliciesAction\x12J\n\"response_body_post_policies_action\x18* \x01(\tR\x1eresponseBodyPostPoliciesAction\"\xee\x08\n\x07Session\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nstart_time\x18\x02 \x01(\x03R\tstartTime\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x31\n\x14\x64\x61tastore_technology\x18\x05 \x01(\tR\x13\x64\x61tastoreTechnology\x12:\n\x19\x64\x61tastore_deployment_type\x18\x06 \x01(\tR\x17\x64\x61tastoreDeploymentType\x12*\n\x11server_ip_address\x18\x07 \x01(\tR\x0fserverIpAddress\x12*\n\x11\x63lient_ip_address\x18\x08 \x01(\tR\x0f\x63lientIpAddress\x12\x17\n\x07user_id\x18\t \x01(\tR\x06userId\x12\x1b\n\tuser_type\x18\n \x01(\tR\x08userType\x12\x17\n\x07\x64\x62_user\x18\x0b \x01(\tR\x06\x64\x62User\x12\x17\n\x07\x64\x62_name\x18\x0c \x01(\tR\x06\x64\x62Name\x12)\n\x10\x61pplication_name\x18\r \x01(\tR\x0f\x61pplicationName\x12\x18\n\x07schemas\x18\x0e \x03(\tR\x07schemas\x12$\n\x0enative_role_id\x18\x0f \x01(\tR\x0cnativeRoleId\x12\x34\n\x16native_role_assignment\x18\x10 \x01(\tR\x14nativeRoleAssignment\x12\x1d\n\nsidecar_id\x18\x11 \x01(\tR\tsidecarId\x12!\n\x0csidecar_name\x18\x12 \x01(\tR\x0bsidecarName\x12-\n\x12sidecar_technology\x18\x13 \x01(\tR\x11sidecarTechnology\x12$\n\x0e\x61ws_account_id\x18\x14 \x01(\tR\x0c\x61wsAccountId\x12\x1d\n\naws_region\x18\x15 \x01(\tR\tawsRegion\x12-\n\x13\x61ws_ec2_instance_id\x18\x16 \x01(\tR\x10\x61wsEc2InstanceId\x12/\n\x14\x61ws_ecs_cluster_name\x18\x17 \x01(\tR\x11\x61wsEcsClusterName\x12-\n\x13\x61ws_ecs_cluster_arn\x18\x18 \x01(\tR\x10\x61wsEcsClusterArn\x12/\n\x14\x61ws_ecs_service_name\x18\x19 \x01(\tR\x11\x61wsEcsServiceName\x12-\n\x13\x61ws_ecs_service_arn\x18\x1a \x01(\tR\x10\x61wsEcsServiceArn\x12%\n\x0f\x61ws_ecs_task_id\x18\x1b \x01(\tR\x0c\x61wsEcsTaskId\x12\'\n\x10\x61ws_ecs_task_arn\x18\x1c \x01(\tR\rawsEcsTaskArn\x12%\n\x0e\x63ontainer_name\x18\x1d \x01(\tR\rcontainerName\"\x9c\x02\n\tFormalLog\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\x12\x34\n\x07session\x18\x03 \x01(\x0b\x32\x1a.admin.v1.types.v1.SessionR\x07session\x12\x37\n\x07request\x18\x04 \x01(\x0b\x32\x1d.admin.v1.types.v1.LogRequestR\x07request\x12\x1d\n\ncreated_at\x18\x05 \x01(\tR\tcreatedAt\x12\x38\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x14\n\x05total\x18\x07 \x01(\x03R\x05total\"\x85\x01\n\x0fTenantLogsInfra\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password\x12\x1a\n\x08username\x18\x03 \x01(\tR\x08username\x12(\n\x10metrics_role_pwd\x18\x04 \x01(\tR\x0emetricsRolePwd\"C\n\x0cLogStorageS3\x12\x33\n\x16s3_firehose_stream_arn\x18\x01 \x01(\tR\x13s3FirehoseStreamArn\"b\n\x12\x43svOrParquetColumn\x12\x1b\n\tcol_index\x18\x01 \x01(\x05R\x08\x63olIndex\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1b\n\tdata_type\x18\x03 \x01(\tR\x08\x64\x61taType\"\xa3\x01\n\x05Image\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1f\n\x0b\x66\x61\x63\x65s_count\x18\x02 \x01(\x05R\nfacesCount\x12\x14\n\x05width\x18\x03 \x01(\x05R\x05width\x12\x16\n\x06height\x18\x04 \x01(\x05R\x06height\x12\x12\n\x04type\x18\x05 \x01(\tR\x04type\x12#\n\rpolicy_action\x18\x06 \x01(\tR\x0cpolicyAction\"\xd9\x01\n\x08S3Object\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12!\n\x0c\x63ontent_type\x18\x02 \x01(\tR\x0b\x63ontentType\x12%\n\x0e\x63ontent_length\x18\x03 \x01(\x03R\rcontentLength\x12?\n\x07\x63olumns\x18\x04 \x03(\x0b\x32%.admin.v1.types.v1.CsvOrParquetColumnR\x07\x63olumns\x12.\n\x05image\x18\x05 \x01(\x0b\x32\x18.admin.v1.types.v1.ImageR\x05image\"\xe2\x04\n\x0eRowLevelMetric\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x02 \x01(\tR\rdatastoreName\x12\x1e\n\x0b\x65nd_user_id\x18\x03 \x01(\tR\tendUserId\x12/\n\x14\x65nd_user_db_username\x18\x04 \x01(\tR\x11\x65ndUserDbUsername\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x17\n\x07\x64\x62_user\x18\x06 \x01(\tR\x06\x64\x62User\x12\x17\n\x07\x64\x62_name\x18\x07 \x01(\tR\x06\x64\x62Name\x12\x1f\n\x0bschema_name\x18\x08 \x01(\tR\nschemaName\x12\x1d\n\ntable_name\x18\t \x01(\tR\ttableName\x12\x12\n\x04path\x18\n \x01(\tR\x04path\x12\x33\n\x16hashed_row_level_value\x18\x0b \x01(\tR\x13hashedRowLevelValue\x12:\n\x1a\x63lear_text_row_level_value\x18\x0c \x01(\tR\x16\x63learTextRowLevelValue\x12*\n\x02ts\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x12\x18\n\x07\x63ounter\x18\x0e \x01(\x03R\x07\x63ounter\x12#\n\rreturned_rows\x18\x0f \x01(\x03R\x0creturnedRows\x12:\n\ntimebucket\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ntimebucket*\xc7\x01\n\nPolicyType\x12\x1b\n\x17POLICY_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19POLICY_TYPE_FILTER_POLICY\x10\x01\x12!\n\x1dPOLICY_TYPE_DECRYPTION_POLICY\x10\x02\x12\x1e\n\x1aPOLICY_TYPE_MASKING_POLICY\x10\x03\x12\x1c\n\x18POLICY_TYPE_BLOCK_POLICY\x10\x04\x12\x1c\n\x18POLICY_TYPE_ALLOW_POLICY\x10\x05\x42\xdb\x01\n\x15\x63om.admin.v1.types.v1B\x08LogProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.log_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\010LogProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_POLICYTYPE']._serialized_start=5895
  _globals['_POLICYTYPE']._serialized_end=6094
  _globals['_TRIGGEREDPOLICY']._serialized_start=180
  _globals['_TRIGGEREDPOLICY']._serialized_end=440
  _globals['_TRIGGEREDFILTERPOLICY']._serialized_start=442
  _globals['_TRIGGEREDFILTERPOLICY']._serialized_end=537
  _globals['_TRIGGEREDDECRYPTIONPOLICY']._serialized_start=539
  _globals['_TRIGGEREDDECRYPTIONPOLICY']._serialized_end=599
  _globals['_TRIGGEREDMASKINGPOLICY']._serialized_start=601
  _globals['_TRIGGEREDMASKINGPOLICY']._serialized_end=721
  _globals['_TRIGGEREDBLOCKPOLICY']._serialized_start=724
  _globals['_TRIGGEREDBLOCKPOLICY']._serialized_end=947
  _globals['_TIGGEREDALLOWPOLICY']._serialized_start=949
  _globals['_TIGGEREDALLOWPOLICY']._serialized_end=1023
  _globals['_LOGREQUEST']._serialized_start=1026
  _globals['_LOGREQUEST']._serialized_end=3164
  _globals['_SESSION']._serialized_start=3167
  _globals['_SESSION']._serialized_end=4301
  _globals['_FORMALLOG']._serialized_start=4304
  _globals['_FORMALLOG']._serialized_end=4588
  _globals['_TENANTLOGSINFRA']._serialized_start=4591
  _globals['_TENANTLOGSINFRA']._serialized_end=4724
  _globals['_LOGSTORAGES3']._serialized_start=4726
  _globals['_LOGSTORAGES3']._serialized_end=4793
  _globals['_CSVORPARQUETCOLUMN']._serialized_start=4795
  _globals['_CSVORPARQUETCOLUMN']._serialized_end=4893
  _globals['_IMAGE']._serialized_start=4896
  _globals['_IMAGE']._serialized_end=5059
  _globals['_S3OBJECT']._serialized_start=5062
  _globals['_S3OBJECT']._serialized_end=5279
  _globals['_ROWLEVELMETRIC']._serialized_start=5282
  _globals['_ROWLEVELMETRIC']._serialized_end=5892
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_github.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!admin/v1/integration_github.proto\x12\x08\x61\x64min.v1\"B\n\x17InstallGithubAppRequest\x12\'\n\x0finstallation_id\x18\x01 \x01(\tR\x0einstallationId\"\x1a\n\x18InstallGithubAppResponse\"\x1b\n\x19GetGithubAppForOrgRequest\"6\n\x1aGetGithubAppForOrgResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message2\xcb\x01\n\rGithubService\x12Y\n\x10InstallGithubApp\x12!.admin.v1.InstallGithubAppRequest\x1a\".admin.v1.InstallGithubAppResponse\x12_\n\x12GetGithubAppForOrg\x12#.admin.v1.GetGithubAppForOrgRequest\x1a$.admin.v1.GetGithubAppForOrgResponseB\xb1\x01\n\x0c\x63om.admin.v1B\x16IntegrationGithubProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_github_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\026IntegrationGithubProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_INSTALLGITHUBAPPREQUEST']._serialized_start=47
  _globals['_INSTALLGITHUBAPPREQUEST']._serialized_end=113
  _globals['_INSTALLGITHUBAPPRESPONSE']._serialized_start=115
  _globals['_INSTALLGITHUBAPPRESPONSE']._serialized_end=141
  _globals['_GETGITHUBAPPFORORGREQUEST']._serialized_start=143
  _globals['_GETGITHUBAPPFORORGREQUEST']._serialized_end=170
  _globals['_GETGITHUBAPPFORORGRESPONSE']._serialized_start=172
  _globals['_GETGITHUBAPPFORORGRESPONSE']._serialized_end=226
  _globals['_GITHUBSERVICE']._serialized_start=229
  _globals['_GITHUBSERVICE']._serialized_end=432
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_slack.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n admin/v1/integration_slack.proto\x12\x08\x61\x64min.v1\"V\n\x1d\x43reateSlackIntegrationRequest\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12!\n\x0credirect_uri\x18\x02 \x01(\tR\x0bredirectUri\" \n\x1e\x43reateSlackIntegrationResponse\"\x1c\n\x1aGetSlackIntegrationRequest\"\xe2\x01\n\x1bGetSlackIntegrationResponse\x12\x17\n\x07team_id\x18\x01 \x01(\tR\x06teamId\x12\x1b\n\tteam_name\x18\x02 \x01(\tR\x08teamName\x12\x1e\n\x0b\x62ot_user_id\x18\x03 \x01(\tR\tbotUserId\x12(\n\x10\x62ot_access_token\x18\x04 \x01(\tR\x0e\x62otAccessToken\x12$\n\x0e\x61uthed_user_id\x18\x05 \x01(\tR\x0c\x61uthedUserId\x12\x1d\n\nchannel_id\x18\x06 \x01(\tR\tchannelId2\xdf\x01\n\x0cSlackService\x12k\n\x16\x43reateSlackIntegration\x12\'.admin.v1.CreateSlackIntegrationRequest\x1a(.admin.v1.CreateSlackIntegrationResponse\x12\x62\n\x13GetSlackIntegration\x12$.admin.v1.GetSlackIntegrationRequest\x1a%.admin.v1.GetSlackIntegrationResponseB\xb0\x01\n\x0c\x63om.admin.v1B\x15IntegrationSlackProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_slack_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\025IntegrationSlackProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATESLACKINTEGRATIONREQUEST']._serialized_start=46
  _globals['_CREATESLACKINTEGRATIONREQUEST']._serialized_end=132
  _globals['_CREATESLACKINTEGRATIONRESPONSE']._serialized_start=134
  _globals['_CREATESLACKINTEGRATIONRESPONSE']._serialized_end=166
  _globals['_GETSLACKINTEGRATIONREQUEST']._serialized_start=168
  _globals['_GETSLACKINTEGRATIONREQUEST']._serialized_end=196
  _globals['_GETSLACKINTEGRATIONRESPONSE']._serialized_start=199
  _globals['_GETSLACKINTEGRATIONRESPONSE']._serialized_end=425
  _globals['_SLACKSERVICE']._serialized_start=428
  _globals['_SLACKSERVICE']._serialized_end=651
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import work_os_pb2 as admin_dot_v1_dot_work__os__pb2


class DSyncServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDirectory = channel.unary_unary(
                '/admin.v1.DSyncService/GetDirectory',
                request_serializer=admin_dot_v1_dot_work__os__pb2.GetDirectoryRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_work__os__pb2.GetDirectoryResponse.FromString,
                )
        self.GetGroupsByDirectoryId = channel.unary_unary(
                '/admin.v1.DSyncService/GetGroupsByDirectoryId',
                request_serializer=admin_dot_v1_dot_work__os__pb2.GetGroupsByDirectoryIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_work__os__pb2.GetGroupsByDirectoryIdResponse.FromString,
                )
        self.GetUsersByDirectoryId = channel.unary_unary(
                '/admin.v1.DSyncService/GetUsersByDirectoryId',
                request_serializer=admin_dot_v1_dot_work__os__pb2.GetUsersByDirectoryIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_work__os__pb2.GetUsersByDirectoryIdResponse.FromString,
                )
        self.GetWorkOsGroupById = channel.unary_unary(
                '/admin.v1.DSyncService/GetWorkOsGroupById',
                request_serializer=admin_dot_v1_dot_work__os__pb2.GetWorkOsGroupByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_work__os__pb2.GetWorkOsGroupByIdResponse.FromString,
                )
        self.GetDirectoryGroups = channel.unary_unary(
                '/admin.v1.DSyncService/GetDirectoryGroups',
                request_serializer=admin_dot_v1_dot_work__os__pb2.GetDirectoryGroupsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_work__os__pb2.GetDirectoryGroupsResponse.FromString,
                )
        self.UpdateDirectoryGroupSync = channel.unary_unary(
                '/admin.v1.DSyncService/UpdateDirectoryGroupSync',
                request_serializer=admin_dot_v1_dot_work__os__pb2.UpdateDirectoryGroupSyncRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_work__os__pb2.UpdateDirectoryGroupSyncResponse.FromString,
                )
        self.GetDSyncPortal = channel.unary_unary(
                '/admin.v1.DSyncService/GetDSyncPortal',
                request_serializer=admin_dot_v1_dot_work__os__pb2.GetDSyncPortalRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_work__os__pb2.GetDSyncPortalResponse.FromString,
                )


class DSyncServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDirectory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroupsByDirectoryId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUsersByDirectoryId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWorkOsGroupById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDirectoryGroups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDirectoryGroupSync(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDSyncPortal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DSyncServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDirectory,
                    request_deserializer=admin_dot_v1_dot_work__os__pb2.GetDirectoryRequest.FromString,
                    response_serializer=admin_dot_v1_dot_work__os__pb2.GetDirectoryResponse.SerializeToString,
            ),
            'GetGroupsByDirectoryId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroupsByDirectoryId,
                    request_deserializer=admin_dot_v1_dot_work__os__pb2.GetGroupsByDirectoryIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_work__os__pb2.GetGroupsByDirectoryIdResponse.SerializeToString,
            ),
            'GetUsersByDirectoryId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsersByDirectoryId,
                    request_deserializer=admin_dot_v1_dot_work__os__pb2.GetUsersByDirectoryIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_work__os__pb2.GetUsersByDirectoryIdResponse.SerializeToString,
            ),
            'GetWorkOsGroupById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWorkOsGroupById,
                    request_deserializer=admin_dot_v1_dot_work__os__pb2.GetWorkOsGroupByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_work__os__pb2.GetWorkOsGroupByIdResponse.SerializeToString,
            ),
            'GetDirectoryGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDirectoryGroups,
                    request_deserializer=admin_dot_v1_dot_work__os__pb2.GetDirectoryGroupsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_work__os__pb2.GetDirectoryGroupsResponse.SerializeToString,
            ),
            'UpdateDirectoryGroupSync': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDirectoryGroupSync,
                    request_deserializer=admin_dot_v1_dot_work__os__pb2.UpdateDirectoryGroupSyncRequest.FromString,
                    response_serializer=admin_dot_v1_dot_work__os__pb2.UpdateDirectoryGroupSyncResponse.SerializeToString,
            ),
            'GetDSyncPortal': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDSyncPortal,
                    request_deserializer=admin_dot_v1_dot_work__os__pb2.GetDSyncPortalRequest.FromString,
                    response_serializer=admin_dot_v1_dot_work__os__pb2.GetDSyncPortalResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.DSyncService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DSyncService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DSyncService/GetDirectory',
            admin_dot_v1_dot_work__os__pb2.GetDirectoryRequest.SerializeToString,
            admin_dot_v1_dot_work__os__pb2.GetDirectoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroupsByDirectoryId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DSyncService/GetGroupsByDirectoryId',
            admin_dot_v1_dot_work__os__pb2.GetGroupsByDirectoryIdRequest.SerializeToString,
            admin_dot_v1_dot_work__os__pb2.GetGroupsByDirectoryIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUsersByDirectoryId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DSyncService/GetUsersByDirectoryId',
            admin_dot_v1_dot_work__os__pb2.GetUsersByDirectoryIdRequest.SerializeToString,
            admin_dot_v1_dot_work__os__pb2.GetUsersByDirectoryIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWorkOsGroupById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DSyncService/GetWorkOsGroupById',
            admin_dot_v1_dot_work__os__pb2.GetWorkOsGroupByIdRequest.SerializeToString,
            admin_dot_v1_dot_work__os__pb2.GetWorkOsGroupByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDirectoryGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DSyncService/GetDirectoryGroups',
            admin_dot_v1_dot_work__os__pb2.GetDirectoryGroupsRequest.SerializeToString,
            admin_dot_v1_dot_work__os__pb2.GetDirectoryGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDirectoryGroupSync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DSyncService/UpdateDirectoryGroupSync',
            admin_dot_v1_dot_work__os__pb2.UpdateDirectoryGroupSyncRequest.SerializeToString,
            admin_dot_v1_dot_work__os__pb2.UpdateDirectoryGroupSyncResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDSyncPortal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DSyncService/GetDSyncPortal',
            admin_dot_v1_dot_work__os__pb2.GetDSyncPortalRequest.SerializeToString,
            admin_dot_v1_dot_work__os__pb2.GetDSyncPortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import encryption_pb2 as admin_dot_v1_dot_encryption__pb2


class FieldEncryptionPolicyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateOrUpdateDefaultFieldEncryptionPolicy = channel.unary_unary(
                '/admin.v1.FieldEncryptionPolicyService/CreateOrUpdateDefaultFieldEncryptionPolicy',
                request_serializer=admin_dot_v1_dot_encryption__pb2.CreateOrUpdateDefaultFieldEncryptionPolicyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_encryption__pb2.CreateOrUpdateDefaultFieldEncryptionPolicyResponse.FromString,
                )
        self.GetDefaultFieldEncryptionPolicy = channel.unary_unary(
                '/admin.v1.FieldEncryptionPolicyService/GetDefaultFieldEncryptionPolicy',
                request_serializer=admin_dot_v1_dot_encryption__pb2.GetDefaultFieldEncryptionPolicyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_encryption__pb2.GetDefaultFieldEncryptionPolicyResponse.FromString,
                )


class FieldEncryptionPolicyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateOrUpdateDefaultFieldEncryptionPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDefaultFieldEncryptionPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FieldEncryptionPolicyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateOrUpdateDefaultFieldEncryptionPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrUpdateDefaultFieldEncryptionPolicy,
                    request_deserializer=admin_dot_v1_dot_encryption__pb2.CreateOrUpdateDefaultFieldEncryptionPolicyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_encryption__pb2.CreateOrUpdateDefaultFieldEncryptionPolicyResponse.SerializeToString,
            ),
            'GetDefaultFieldEncryptionPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDefaultFieldEncryptionPolicy,
                    request_deserializer=admin_dot_v1_dot_encryption__pb2.GetDefaultFieldEncryptionPolicyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_encryption__pb2.GetDefaultFieldEncryptionPolicyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.FieldEncryptionPolicyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FieldEncryptionPolicyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateOrUpdateDefaultFieldEncryptionPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.FieldEncryptionPolicyService/CreateOrUpdateDefaultFieldEncryptionPolicy',
            admin_dot_v1_dot_encryption__pb2.CreateOrUpdateDefaultFieldEncryptionPolicyRequest.SerializeToString,
            admin_dot_v1_dot_encryption__pb2.CreateOrUpdateDefaultFieldEncryptionPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDefaultFieldEncryptionPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.FieldEncryptionPolicyService/GetDefaultFieldEncryptionPolicy',
            admin_dot_v1_dot_encryption__pb2.GetDefaultFieldEncryptionPolicyRequest.SerializeToString,
            admin_dot_v1_dot_encryption__pb2.GetDefaultFieldEncryptionPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class FieldEncryptionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateFieldEncryption = channel.unary_unary(
                '/admin.v1.FieldEncryptionService/CreateFieldEncryption',
                request_serializer=admin_dot_v1_dot_encryption__pb2.CreateFieldEncryptionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_encryption__pb2.CreateFieldEncryptionResponse.FromString,
                )
        self.GetFieldEncryptionsByDatastore = channel.unary_unary(
                '/admin.v1.FieldEncryptionService/GetFieldEncryptionsByDatastore',
                request_serializer=admin_dot_v1_dot_encryption__pb2.GetFieldEncryptionsByDatastoreRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_encryption__pb2.GetFieldEncryptionsByDatastoreResponse.FromString,
                )
        self.DeleteFieldEncryption = channel.unary_unary(
                '/admin.v1.FieldEncryptionService/DeleteFieldEncryption',
                request_serializer=admin_dot_v1_dot_encryption__pb2.DeleteFieldEncryptionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_encryption__pb2.DeleteFieldEncryptionResponse.FromString,
                )


class FieldEncryptionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateFieldEncryption(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFieldEncryptionsByDatastore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFieldEncryption(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FieldEncryptionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateFieldEncryption': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFieldEncryption,
                    request_deserializer=admin_dot_v1_dot_encryption__pb2.CreateFieldEncryptionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_encryption__pb2.CreateFieldEncryptionResponse.SerializeToString,
            ),
            'GetFieldEncryptionsByDatastore': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFieldEncryptionsByDatastore,
                    request_deserializer=admin_dot_v1_dot_encryption__pb2.GetFieldEncryptionsByDatastoreRequest.FromString,
                    response_serializer=admin_dot_v1_dot_encryption__pb2.GetFieldEncryptionsByDatastoreResponse.SerializeToString,
            ),
            'DeleteFieldEncryption': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFieldEncryption,
                    request_deserializer=admin_dot_v1_dot_encryption__pb2.DeleteFieldEncryptionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_encryption__pb2.DeleteFieldEncryptionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.FieldEncryptionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FieldEncryptionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateFieldEncryption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.FieldEncryptionService/CreateFieldEncryption',
            admin_dot_v1_dot_encryption__pb2.CreateFieldEncryptionRequest.SerializeToString,
            admin_dot_v1_dot_encryption__pb2.CreateFieldEncryptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFieldEncryptionsByDatastore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.FieldEncryptionService/GetFieldEncryptionsByDatastore',
            admin_dot_v1_dot_encryption__pb2.GetFieldEncryptionsByDatastoreRequest.SerializeToString,
            admin_dot_v1_dot_encryption__pb2.GetFieldEncryptionsByDatastoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFieldEncryption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.FieldEncryptionService/DeleteFieldEncryption',
            admin_dot_v1_dot_encryption__pb2.DeleteFieldEncryptionRequest.SerializeToString,
            admin_dot_v1_dot_encryption__pb2.DeleteFieldEncryptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import integration_log_pb2 as admin_dot_v1_dot_types_dot_v1_dot_integration__log__pb2
from .types.v1 import log_link_pb2 as admin_dot_v1_dot_types_dot_v1_dot_log__link__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_log.proto\x12\x08\x61\x64min.v1\x1a\'admin/v1/types/v1/integration_log.proto\x1a admin/v1/types/v1/log_link.proto\"\xe6\x01\n\x1c\x43reateIntegrationLogsRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x17\n\x07\x64\x64_site\x18\x03 \x01(\tR\x06\x64\x64Site\x12\x1c\n\ndd_api_key\x18\x04 \x01(\tR\x08\x64\x64\x41piKey\x12\"\n\rdd_account_id\x18\x05 \x01(\tR\x0b\x64\x64\x41\x63\x63ountId\x12\x1d\n\nsplunk_url\x18\x06 \x01(\tR\tsplunkUrl\x12$\n\x0esplunk_api_key\x18\x07 \x01(\tR\x0csplunkApiKey\"e\n\x1d\x43reateIntegrationLogsResponse\x12\x44\n\x0bintegration\x18\x01 \x01(\x0b\x32\".admin.v1.types.v1.IntegrationLogsR\x0bintegration\"\x1b\n\x19GetIntegrationLogsRequest\"d\n\x1aGetIntegrationLogsResponse\x12\x46\n\x0cintegrations\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.IntegrationLogsR\x0cintegrations\".\n\x1cGetIntegrationLogByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"e\n\x1dGetIntegrationLogByIdResponse\x12\x44\n\x0bintegration\x18\x01 \x01(\x0b\x32\".admin.v1.types.v1.IntegrationLogsR\x0bintegration\".\n\x1c\x44\x65leteIntegrationLogsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1f\n\x1d\x44\x65leteIntegrationLogsResponse\"e\n\x19\x43reateLogsLinkItemRequest\x12%\n\x0eintegration_id\x18\x01 \x01(\tR\rintegrationId\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\"`\n\x1a\x43reateLogsLinkItemResponse\x12\x42\n\rlog_item_link\x18\x01 \x01(\x0b\x32\x1e.admin.v1.types.v1.LogLinkItemR\x0blogItemLink\",\n\x1aGetLogsLinkItemByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"c\n\x1bGetLogsLinkItemByIdResponse\x12\x44\n\x0elog_item_links\x18\x01 \x01(\x0b\x32\x1e.admin.v1.types.v1.LogLinkItemR\x0clogItemLinks\"+\n\x19\x44\x65leteLogsLinkItemRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1c\n\x1a\x44\x65leteLogsLinkItemResponse2\xd2\x05\n\x0bLogsService\x12h\n\x15\x43reateIntegrationLogs\x12&.admin.v1.CreateIntegrationLogsRequest\x1a\'.admin.v1.CreateIntegrationLogsResponse\x12_\n\x12GetIntegrationLogs\x12#.admin.v1.GetIntegrationLogsRequest\x1a$.admin.v1.GetIntegrationLogsResponse\x12h\n\x15GetIntegrationLogById\x12&.admin.v1.GetIntegrationLogByIdRequest\x1a\'.admin.v1.GetIntegrationLogByIdResponse\x12h\n\x15\x44\x65leteIntegrationLogs\x12&.admin.v1.DeleteIntegrationLogsRequest\x1a\'.admin.v1.DeleteIntegrationLogsResponse\x12_\n\x12\x43reateLogsLinkItem\x12#.admin.v1.CreateLogsLinkItemRequest\x1a$.admin.v1.CreateLogsLinkItemResponse\x12\x62\n\x13GetLogsLinkItemById\x12$.admin.v1.GetLogsLinkItemByIdRequest\x1a%.admin.v1.GetLogsLinkItemByIdResponse\x12_\n\x12\x44\x65leteLogsLinkItem\x12#.admin.v1.DeleteLogsLinkItemRequest\x1a$.admin.v1.DeleteLogsLinkItemResponseB\xae\x01\n\x0c\x63om.admin.v1B\x13IntegrationLogProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_log_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationLogProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEINTEGRATIONLOGSREQUEST']._serialized_start=120
  _globals['_CREATEINTEGRATIONLOGSREQUEST']._serialized_end=350
  _globals['_CREATEINTEGRATIONLOGSRESPONSE']._serialized_start=352
  _globals['_CREATEINTEGRATIONLOGSRESPONSE']._serialized_end=453
  _globals['_GETINTEGRATIONLOGSREQUEST']._serialized_start=455
  _globals['_GETINTEGRATIONLOGSREQUEST']._serialized_end=482
  _globals['_GETINTEGRATIONLOGSRESPONSE']._serialized_start=484
  _globals['_GETINTEGRATIONLOGSRESPONSE']._serialized_end=584
  _globals['_GETINTEGRATIONLOGBYIDREQUEST']._serialized_start=586
  _globals['_GETINTEGRATIONLOGBYIDREQUEST']._serialized_end=632
  _globals['_GETINTEGRATIONLOGBYIDRESPONSE']._serialized_start=634
  _globals['_GETINTEGRATIONLOGBYIDRESPONSE']._serialized_end=735
  _globals['_DELETEINTEGRATIONLOGSREQUEST']._serialized_start=737
  _globals['_DELETEINTEGRATIONLOGSREQUEST']._serialized_end=783
  _globals['_DELETEINTEGRATIONLOGSRESPONSE']._serialized_start=785
  _globals['_DELETEINTEGRATIONLOGSRESPONSE']._serialized_end=816
  _globals['_CREATELOGSLINKITEMREQUEST']._serialized_start=818
  _globals['_CREATELOGSLINKITEMREQUEST']._serialized_end=919
  _globals['_CREATELOGSLINKITEMRESPONSE']._serialized_start=921
  _globals['_CREATELOGSLINKITEMRESPONSE']._serialized_end=1017
  _globals['_GETLOGSLINKITEMBYIDREQUEST']._serialized_start=1019
  _globals['_GETLOGSLINKITEMBYIDREQUEST']._serialized_end=1063
  _globals['_GETLOGSLINKITEMBYIDRESPONSE']._serialized_start=1065
  _globals['_GETLOGSLINKITEMBYIDRESPONSE']._serialized_end=1164
  _globals['_DELETELOGSLINKITEMREQUEST']._serialized_start=1166
  _globals['_DELETELOGSLINKITEMREQUEST']._serialized_end=1209
  _globals['_DELETELOGSLINKITEMRESPONSE']._serialized_start=1211
  _globals['_DELETELOGSLINKITEMRESPONSE']._serialized_end=1239
  _globals['_LOGSSERVICE']._serialized_start=1242
  _globals['_LOGSSERVICE']._serialized_end=1964
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SearchUser(_message.Message):
    __slots__ = ["id", "db_username", "created_at", "active", "type", "status", "expire_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DB_USERNAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    db_username: str
    created_at: _timestamp_pb2.Timestamp
    active: bool
    type: str
    status: str
    expire_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., db_username: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., active: bool = ..., type: _Optional[str] = ..., status: _Optional[str] = ..., expire_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SearchGroup(_message.Message):
    __slots__ = ["id", "name", "description", "status", "created_at", "active"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    status: str
    created_at: _timestamp_pb2.Timestamp
    active: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., status: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., active: bool = ...) -> None: ...

class SearchPolicy(_message.Message):
    __slots__ = ["id", "name", "description", "status", "created_by", "created_at", "updated_at", "active"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    status: str
    created_by: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    active: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., status: _Optional[str] = ..., created_by: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., active: bool = ...) -> None: ...

class SearchDatastore(_message.Message):
    __slots__ = ["id", "datastore_id", "name", "hostname", "technology", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    datastore_id: str
    name: str
    hostname: str
    technology: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., name: _Optional[str] = ..., hostname: _Optional[str] = ..., technology: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SearchSidecar(_message.Message):
    __slots__ = ["id", "datastore_id", "name", "formal_hostname", "cloud_provider", "cloud_region", "deployment_type", "fail_open", "technology", "proxy_status", "server_connection_status", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    FORMAL_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    CLOUD_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    CLOUD_REGION_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    FAIL_OPEN_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    PROXY_STATUS_FIELD_NUMBER: _ClassVar[int]
    SERVER_CONNECTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    datastore_id: str
    name: str
    formal_hostname: str
    cloud_provider: str
    cloud_region: str
    deployment_type: str
    fail_open: bool
    technology: str
    proxy_status: str
    server_connection_status: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., name: _Optional[str] = ..., formal_hostname: _Optional[str] = ..., cloud_provider: _Optional[str] = ..., cloud_region: _Optional[str] = ..., deployment_type: _Optional[str] = ..., fail_open: bool = ..., technology: _Optional[str] = ..., proxy_status: _Optional[str] = ..., server_connection_status: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SearchInventory(_message.Message):
    __slots__ = ["created_at", "updated_at", "datastore_id", "datastore_name", "path", "table_physical_id", "table_attribute_number", "name", "alias", "table_path", "data_label", "data_type", "data_type_oid", "data_label_locked_for_sidecar", "tags", "encrypted", "data_labels"]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TABLE_PHYSICAL_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_ATTRIBUTE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_OID_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_LOCKED_FOR_SIDECAR_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    DATA_LABELS_FIELD_NUMBER: _ClassVar[int]
    created_at: int
    updated_at: int
    datastore_id: str
    datastore_name: str
    path: str
    table_physical_id: str
    table_attribute_number: int
    name: str
    alias: str
    table_path: str
    data_label: str
    data_type: str
    data_type_oid: int
    data_label_locked_for_sidecar: bool
    tags: _containers.RepeatedScalarFieldContainer[str]
    encrypted: bool
    data_labels: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, created_at: _Optional[int] = ..., updated_at: _Optional[int] = ..., datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., path: _Optional[str] = ..., table_physical_id: _Optional[str] = ..., table_attribute_number: _Optional[int] = ..., name: _Optional[str] = ..., alias: _Optional[str] = ..., table_path: _Optional[str] = ..., data_label: _Optional[str] = ..., data_type: _Optional[str] = ..., data_type_oid: _Optional[int] = ..., data_label_locked_for_sidecar: bool = ..., tags: _Optional[_Iterable[str]] = ..., encrypted: bool = ..., data_labels: _Optional[_Iterable[str]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetOutputsRequest(_message.Message):
    __slots__ = ["item_id"]
    ITEM_ID_FIELD_NUMBER: _ClassVar[int]
    item_id: str
    def __init__(self, item_id: _Optional[str] = ...) -> None: ...

class GetOutputsResponse(_message.Message):
    __slots__ = ["records"]
    RECORDS_FIELD_NUMBER: _ClassVar[int]
    records: _containers.RepeatedCompositeFieldContainer[OutputRecord]
    def __init__(self, records: _Optional[_Iterable[_Union[OutputRecord, _Mapping]]] = ...) -> None: ...

class OutputRecord(_message.Message):
    __slots__ = ["id", "item_id", "message", "created_at", "log_level"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ITEM_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    LOG_LEVEL_FIELD_NUMBER: _ClassVar[int]
    id: str
    item_id: str
    message: str
    created_at: _timestamp_pb2.Timestamp
    log_level: str
    def __init__(self, id: _Optional[str] = ..., item_id: _Optional[str] = ..., message: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., log_level: _Optional[str] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExternalId(_message.Message):
    __slots__ = ["id", "external_id", "app_id", "db_user_id", "description", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    APP_ID_FIELD_NUMBER: _ClassVar[int]
    DB_USER_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    external_id: str
    app_id: str
    db_user_id: str
    description: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., external_id: _Optional[str] = ..., app_id: _Optional[str] = ..., db_user_id: _Optional[str] = ..., description: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/types/v1/search.proto\x12\x11\x61\x64min.v1.types.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf5\x01\n\nSearchUser\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x64\x62_username\x18\x02 \x01(\tR\ndbUsername\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x12\n\x04type\x18\x05 \x01(\tR\x04type\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\"\xbe\x01\n\x0bSearchGroup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x16\n\x06\x61\x63tive\x18\x07 \x01(\x08R\x06\x61\x63tive\"\x99\x02\n\x0cSearchPolicy\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x1d\n\ncreated_by\x18\x05 \x01(\tR\tcreatedBy\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x16\n\x06\x61\x63tive\x18\x08 \x01(\x08R\x06\x61\x63tive\"\xcf\x01\n\x0fSearchDatastore\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x1a\n\x08hostname\x18\x04 \x01(\tR\x08hostname\x12\x1e\n\ntechnology\x18\x05 \x01(\tR\ntechnology\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\xc7\x03\n\rSearchSidecar\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\'\n\x0f\x66ormal_hostname\x18\x04 \x01(\tR\x0e\x66ormalHostname\x12%\n\x0e\x63loud_provider\x18\x05 \x01(\tR\rcloudProvider\x12!\n\x0c\x63loud_region\x18\x06 \x01(\tR\x0b\x63loudRegion\x12\'\n\x0f\x64\x65ployment_type\x18\x07 \x01(\tR\x0e\x64\x65ploymentType\x12\x1b\n\tfail_open\x18\x08 \x01(\x08R\x08\x66\x61ilOpen\x12\x1e\n\ntechnology\x18\t \x01(\tR\ntechnology\x12!\n\x0cproxy_status\x18\n \x01(\tR\x0bproxyStatus\x12\x38\n\x18server_connection_status\x18\x0b \x01(\tR\x16serverConnectionStatus\x12\x39\n\ncreated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\xcd\x04\n\x0fSearchInventory\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12*\n\x11table_physical_id\x18\x06 \x01(\tR\x0ftablePhysicalId\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x14\n\x05\x61lias\x18\t \x01(\tR\x05\x61lias\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\x12\x1f\n\x0b\x64\x61ta_labels\x18\x11 \x03(\tR\ndataLabelsB\xde\x01\n\x15\x63om.admin.v1.types.v1B\x0bSearchProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.search_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\013SearchProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_SEARCHUSER']._serialized_start=87
  _globals['_SEARCHUSER']._serialized_end=332
  _globals['_SEARCHGROUP']._serialized_start=335
  _globals['_SEARCHGROUP']._serialized_end=525
  _globals['_SEARCHPOLICY']._serialized_start=528
  _globals['_SEARCHPOLICY']._serialized_end=809
  _globals['_SEARCHDATASTORE']._serialized_start=812
  _globals['_SEARCHDATASTORE']._serialized_end=1019
  _globals['_SEARCHSIDECAR']._serialized_start=1022
  _globals['_SEARCHSIDECAR']._serialized_end=1477
  _globals['_SEARCHINVENTORY']._serialized_start=1480
  _globals['_SEARCHINVENTORY']._serialized_end=2069
# @@protoc_insertion_point(module_scope)
